From a50f7fbb6e8251ac7bf648b26ea1e6d168ffedc4 Mon Sep 17 00:00:00 2001
From: mattab <matthieu.aubry@gmail.com>
Date: Tue, 15 Nov 2016 01:32:05 +1300
Subject: [PATCH] Bandwidth is a tracker plugin

---
 tests/PHPUnit/Integration/Plugin/ManagerTest.php | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/tests/PHPUnit/Integration/Plugin/ManagerTest.php b/tests/PHPUnit/Integration/Plugin/ManagerTest.php
index 5822e22c05..ff99dbe0b1 100644
--- a/tests/PHPUnit/Integration/Plugin/ManagerTest.php
+++ b/tests/PHPUnit/Integration/Plugin/ManagerTest.php
@@ -147,8 +147,8 @@ class ManagerTest extends IntegrationTestCase
 
     private function assertOnlyTrackerPluginsAreLoaded($expectedPluginNamesLoaded)
     {
-        // should currently load between 10 and 25 plugins
-        $this->assertLessThan(25, count($this->manager->getLoadedPlugins()));
+        // should currently load between 10 and 26 plugins
+        $this->assertLessThan(26, count($this->manager->getLoadedPlugins()));
         $this->assertGreaterThan(10, count($this->manager->getLoadedPlugins()));
 
         // we need to make sure it actually only loaded the correct ones
-- 
GitLab